# SPDX-FileCopyrightText: 2025 Florian Obersteiner <f.obersteiner@kit.edu>
#
# SPDX-License-Identifier: GPL-3.0-or-later

from datetime import datetime
from pathlib import Path
from typing import Iterable

import pandas as pd
import xarray as xr

rename_config = {"PosLong": "lon", "PosLat": "lat", "Altitude": "alt"}


def loader(paths: Iterable[Path], config: dict) -> pd.DataFrame:
    """
    Load multiple netCDF files into a single DataFrame.
    """
    dataframes = []
    for path in sorted(paths):
        df = xr.open_dataset(path).to_dataframe()
        # replace column names with more reasonable ones
        df = df.rename(columns=rename_config)
        # extract flight number and date from filename; add as extra columns
        df["flight_number"] = int(path.name.split("_")[2])
        df["date"] = datetime.strptime(path.stem.split("_")[1], "%Y%m%d").strftime("%Y-%m-%d")
        # make a linear interpolation of the acetonitrile column for BB flaggin
        if "ACN" in df.columns:
            df["BB_flag"] = df["ACN"].interpolate() > config["BB_THRESH"]
        dataframes.append(df)

    return pd.concat(dataframes)
